Crate webrtc_audio_processing_config

Crate webrtc_audio_processing_config 

This crate provides config structs for webrtc-audio-processing without any FFI and with only minimal dependencies. Handy when you want to configure it from e.g. WASM project.

Structs

AdaptiveDigital
Parameters for the adaptive digital controller, which adjusts and applies a digital gain after echo cancellation and after noise suppression.
AnalogGainController
Enables the analog gain controller functionality.
AnalogMicGainEmulation
Analog mic gain emulation for capture level adjustment.
CaptureAmplifierIter
An iterator over the variants of CaptureAmplifier
CaptureLevelAdjustment
Functionality for general level adjustment in the capture pipeline. This should not be used together with the legacy PreAmplifier functionality.
ClippingPredictor
Enables clipping prediction functionality.
ClippingPredictorModeIter
An iterator over the variants of ClippingPredictorMode
Config
The parameters and behavior of the audio processing module are controlled by changing the default values in this Config struct. The config is applied by passing the struct to the Processor::set_config() method.
DownmixMethodIter
An iterator over the variants of DownmixMethod
EchoCancellerIter
An iterator over the variants of EchoCanceller
FixedDigital
Parameters for the fixed digital controller, which applies a fixed digital gain after the adaptive digital controller and before the limiter.
GainController1
Enables automatic gain control (AGC) functionality. The automatic gain control (AGC) component brings the signal to an appropriate range. This is done by applying a digital gain directly and, in the analog mode, prescribing an analog gain to be applied at the audio HAL. Recommended to be enabled on the client-side.
GainController2
Parameters for AGC2, an Automatic Gain Control (AGC) sub-module which replaces the AGC sub-module parameterized by gain_controller1. AGC2 brings the captured audio signal to the desired level by combining three different controllers (namely, input volume controller, adaptive digital controller and fixed digital controller) and a limiter.
GainControllerIter
An iterator over the variants of GainController
GainControllerModeIter
An iterator over the variants of GainControllerMode
HighPassFilter
HPF (high-pass filter) configuration.
NoiseSuppression
Enables background noise suppression.
NoiseSuppressionLevelIter
An iterator over the variants of NoiseSuppressionLevel
Pipeline
Sets the properties of the audio processing pipeline.
PipelineProcessingRateIter
An iterator over the variants of PipelineProcessingRate
PreAmplifier
The PreAmplifier amplifies the capture signal before any other processing is done. TODO(webrtc:5298): Will be deprecated to use the pre-gain functionality in capture_level_adjustment instead.

Enums

CaptureAmplifier
A choice of capture-side pre-amplification/volume adjustment.
ClippingPredictorMode
Clipping predictor mode.
DownmixMethod
Downmix method for multi-channel capture audio.
EchoCanceller
AEC (acoustic echo cancellation) configuration. Defaults to Full (AEC3) mode with delay estimation (stream_delay unset).
GainController
A choice of the gain controller implementation.
GainControllerMode
Gain control mode.
NoiseSuppressionLevel
Noise suppression level.
PipelineProcessingRate
Internal processing rate.