pub struct AdaptiveDigital {
pub headroom_db: f32,
pub max_gain_db: f32,
pub initial_gain_db: f32,
pub max_gain_change_db_per_second: f32,
pub max_output_noise_level_dbfs: f32,
}Expand description
Parameters for the adaptive digital controller, which adjusts and applies a digital gain after echo cancellation and after noise suppression.
Fields
headroom_db: f32Headroom (dB).
max_gain_db: f32Max gain (dB).
initial_gain_db: f32Initial gain (dB).
max_gain_change_db_per_second: f32Max gain change speed (dB/s).
max_output_noise_level_dbfs: f32Max output noise level (dBFS).