pub struct AnalogGainController {
pub startup_min_volume: i32,
pub clipped_level_min: i32,
pub enable_digital_adaptive: bool,
pub clipped_level_step: i32,
pub clipped_ratio_threshold: f32,
pub clipped_wait_frames: i32,
pub clipping_predictor: Option<ClippingPredictor>,
}Expand description
Enables the analog gain controller functionality.
Fields
startup_min_volume: i32TODO(bugs.webrtc.org/7494): Will be deprecated.
clipped_level_min: i32Lowest analog microphone level that will be applied in response to clipping.
enable_digital_adaptive: boolIf true, an adaptive digital gain is applied.
clipped_level_step: i32Amount the microphone level is lowered with every clipping event. Limited to (0, 255].
clipped_ratio_threshold: f32Proportion of clipped samples required to declare a clipping event. Limited to (0.f, 1.f).
clipped_wait_frames: i32Time in frames to wait after a clipping event before checking again. Limited to values higher than 0.
clipping_predictor: Option<ClippingPredictor>Clipping predictor.