pub struct CaptureLevelAdjustment {
pub pre_gain_factor: f32,
pub post_gain_factor: f32,
pub analog_mic_gain_emulation: Option<AnalogMicGainEmulation>,
}Expand description
Functionality for general level adjustment in the capture pipeline. This should not be used together with the legacy PreAmplifier functionality.
Fields
pre_gain_factor: f32The pre_gain_factor scales the signal before any processing is done.
post_gain_factor: f32The post_gain_factor scales the signal after all processing is done.
analog_mic_gain_emulation: Option<AnalogMicGainEmulation>Analog mic gain emulation.