pub struct FixedDigital {
pub gain_db: f32,
}Expand description
Parameters for the fixed digital controller, which applies a fixed digital gain after the adaptive digital controller and before the limiter.
Fields
gain_db: f32By setting gain_db to a value greater than zero, the limiter can be
turned into a compressor that first applies a fixed gain.