pub struct GainController2 {
pub input_volume_controller_enabled: bool,
pub adaptive_digital: Option<AdaptiveDigital>,
pub fixed_digital: FixedDigital,
}Expand description
Parameters for AGC2, an Automatic Gain Control (AGC) sub-module which
replaces the AGC sub-module parameterized by gain_controller1.
AGC2 brings the captured audio signal to the desired level by combining
three different controllers (namely, input volume controller, adaptive
digital controller and fixed digital controller) and a limiter.
Fields
input_volume_controller_enabled: boolEnables the input volume controller, which adjusts the input volume applied when the audio is captured (e.g., microphone volume on a soundcard, input volume on HAL).
adaptive_digital: Option<AdaptiveDigital>Parameters for the adaptive digital controller, which adjusts and applies a digital gain after echo cancellation and after noise suppression.
fixed_digital: FixedDigitalParameters for the fixed digital controller, which applies a fixed digital gain after the adaptive digital controller and before the limiter.