This crate provides config structs for webrtc-audio-processing without any FFI and with only
minimal dependencies. Handy when you want to configure it from e.g. WASM project.
Structs
- Adaptive
Digital - Parameters for the adaptive digital controller, which adjusts and applies a digital gain after echo cancellation and after noise suppression.
- Analog
Gain Controller - Enables the analog gain controller functionality.
- Analog
MicGain Emulation - Analog mic gain emulation for capture level adjustment.
- Capture
Amplifier Iter - An iterator over the variants of CaptureAmplifier
- Capture
Level Adjustment - Functionality for general level adjustment in the capture pipeline. This should not be used together with the legacy PreAmplifier functionality.
- Clipping
Predictor - Enables clipping prediction functionality.
- Clipping
Predictor Mode Iter - An iterator over the variants of ClippingPredictorMode
- Config
- The parameters and behavior of the audio processing module are controlled
by changing the default values in this
Configstruct. The config is applied by passing the struct to theProcessor::set_config()method. - Downmix
Method Iter - An iterator over the variants of DownmixMethod
- Echo
Canceller Iter - An iterator over the variants of EchoCanceller
- Fixed
Digital - Parameters for the fixed digital controller, which applies a fixed digital gain after the adaptive digital controller and before the limiter.
- Gain
Controller1 - Enables automatic gain control (AGC) functionality. The automatic gain control (AGC) component brings the signal to an appropriate range. This is done by applying a digital gain directly and, in the analog mode, prescribing an analog gain to be applied at the audio HAL. Recommended to be enabled on the client-side.
- Gain
Controller2 - Parameters for AGC2, an Automatic Gain Control (AGC) sub-module which
replaces the AGC sub-module parameterized by
gain_controller1. AGC2 brings the captured audio signal to the desired level by combining three different controllers (namely, input volume controller, adaptive digital controller and fixed digital controller) and a limiter. - Gain
Controller Iter - An iterator over the variants of GainController
- Gain
Controller Mode Iter - An iterator over the variants of GainControllerMode
- High
Pass Filter - HPF (high-pass filter) configuration.
- Noise
Suppression - Enables background noise suppression.
- Noise
Suppression Level Iter - An iterator over the variants of NoiseSuppressionLevel
- Pipeline
- Sets the properties of the audio processing pipeline.
- Pipeline
Processing Rate Iter - An iterator over the variants of PipelineProcessingRate
- PreAmplifier
- The
PreAmplifieramplifies the capture signal before any other processing is done. TODO(webrtc:5298): Will be deprecated to use the pre-gain functionality in capture_level_adjustment instead.
Enums
- Capture
Amplifier - A choice of capture-side pre-amplification/volume adjustment.
- Clipping
Predictor Mode - Clipping predictor mode.
- Downmix
Method - Downmix method for multi-channel capture audio.
- Echo
Canceller - AEC (acoustic echo cancellation) configuration. Defaults to Full (AEC3) mode with delay estimation (stream_delay unset).
- Gain
Controller - A choice of the gain controller implementation.
- Gain
Controller Mode - Gain control mode.
- Noise
Suppression Level - Noise suppression level.
- Pipeline
Processing Rate - Internal processing rate.