pub enum GainControllerMode {
AdaptiveAnalog,
AdaptiveDigital,
FixedDigital,
}Expand description
Gain control mode.
Variants
AdaptiveAnalog
Adaptive mode intended for use if an analog volume control is available on the capture device. It will require the user to provide coupling between the OS mixer controls and AGC through the stream_analog_level() functions. It consists of an analog gain prescription for the audio device and a digital compression stage.
AdaptiveDigital
Adaptive mode intended for situations in which an analog volume control is unavailable. It operates in a similar fashion to the adaptive analog mode, but with scaling instead applied in the digital domain. As with the analog mode, it additionally uses a digital compression stage.
FixedDigital
Fixed mode which enables only the digital compression stage also used by the two adaptive modes. It is distinguished from the adaptive modes by considering only a short time-window of the input signal. It applies a fixed gain through most of the input level range, and compresses (gradually reduces gain with increasing level) the input signal at higher levels. This mode is preferred on embedded devices where the capture signal level is predictable, so that a known gain can be applied.