ClippingPredictor

Struct ClippingPredictor 

pub struct ClippingPredictor {
    pub mode: ClippingPredictorMode,
    pub window_length: i32,
    pub reference_window_length: i32,
    pub reference_window_delay: i32,
    pub clipping_threshold: f32,
    pub crest_factor_margin: f32,
    pub use_predicted_step: bool,
}
Enables clipping prediction functionality.

Fields

mode: ClippingPredictorMode

Mode.

window_length: i32

Number of frames in the sliding analysis window.

reference_window_length: i32

Number of frames in the sliding reference window.

reference_window_delay: i32

Reference window delay (unit: number of frames).

clipping_threshold: f32

Clipping prediction threshold (dBFS).

crest_factor_margin: f32

Crest factor drop threshold (dB).

use_predicted_step: bool

If true, the recommended clipped level step is used to modify the analog gain. Otherwise, the predictor runs without affecting the analog gain.