pub struct Config {
pub pipeline: Pipeline,
pub capture_amplifier: Option<CaptureAmplifier>,
pub high_pass_filter: Option<HighPassFilter>,
pub echo_canceller: Option<EchoCanceller>,
pub noise_suppression: Option<NoiseSuppression>,
pub gain_controller: Option<GainController>,
}Expand description
The parameters and behavior of the audio processing module are controlled
by changing the default values in this Config struct.
The config is applied by passing the struct to the
Processor::set_config() method.
Fields
pipeline: PipelineSets the properties of the audio processing pipeline.
capture_amplifier: Option<CaptureAmplifier>Enables and configures capture-side pre-amplifier/capture-level adjustment.
high_pass_filter: Option<HighPassFilter>Enables and configures high pass filter. Strongly recommended if echo cancellation is enabled. Enabling AECM or noise suppression force-enables high pass filter.
echo_canceller: Option<EchoCanceller>Enables and configures acoustic echo cancellation.
noise_suppression: Option<NoiseSuppression>Enables and configures background noise suppression. Force-enables high pass filtering.
gain_controller: Option<GainController>Enables and configures automatic gain control (v1 or v2).