pub struct GainController1 {
pub mode: GainControllerMode,
pub target_level_dbfs: u8,
pub compression_gain_db: u8,
pub enable_limiter: bool,
pub analog_gain_controller: Option<AnalogGainController>,
}Expand description
Enables automatic gain control (AGC) functionality. The automatic gain control (AGC) component brings the signal to an appropriate range. This is done by applying a digital gain directly and, in the analog mode, prescribing an analog gain to be applied at the audio HAL. Recommended to be enabled on the client-side.
Fields
mode: GainControllerModeAGC mode.
target_level_dbfs: u8Sets the target peak level (or envelope) of the AGC in dBFs (decibels from digital full-scale). The convention is to use positive values. For instance, passing in a value of 3 corresponds to -3 dBFs, or a target level 3 dB below full-scale. Limited to [0, 31].
compression_gain_db: u8Sets the maximum gain the digital compression stage may apply, in dB. A higher number corresponds to greater compression, while a value of 0 will leave the signal uncompressed. Limited to [0, 90].
For updates after APM setup, the C++ upstream suggests using RuntimeSetting instead (which is not yet exposed in the Rust wrapper).
enable_limiter: boolWhen enabled, the compression stage will hard limit the signal to the target level. Otherwise, the signal will be compressed but not limited above the target level.
analog_gain_controller: Option<AnalogGainController>Analog gain controller configuration.